@@ -1,207 +1,39 @@
-/*                                                                              
- * PDFedit - free program for PDF document manipulation.                        
- * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
- *                                              Miroslav Jahoda,       
- *                                              Jozef Misutka, 
- *                                              Martin Petricek                                             
+/*
+ * PDFedit - free program for PDF document manipulation.
+ * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
+ *                                              Miroslav Jahoda,
+ *                                              Jozef Misutka,
+ *                                              Martin Petricek
  *
- * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
- */ 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 2 of the License.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in doc/LICENSE.GPL); if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+ * MA  02111-1307  USA
+ *
+ * Project is hosted on http://sourceforge.net/projects/pdfedit
+ */
 // vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 
 #ifndef _COBJECTHELPERS_H_
 #define _COBJECTHELPERS_H_
 
-/*
- * $RCSfile: cobjecthelpers.h,v $
- *
- * $Log: cobjecthelpers.h,v $
- * Revision 1.39  2007/04/25 18:24:35  bilboq
- *
- * applied patch from Martin Michlmayr to fix compilation with gcc-4.3
- *
- * fixed some typos in comments
- *
- * Revision 1.38  2007/04/11 20:58:49  bilboq
- *
- * kernel doxygen comment fixes
- *
- * c++ impl of transformMatrixDiv
- *
- * doc & changelog update
- *
- * Revision 1.37  2007/02/04 20:17:02  mstsxfx
- * Common Licence comment for all cc and h files available in doc/licence_header
- * file and its content to all cc and h files in src/{gui,kernel,utils}
- * directories.
- * Xpdf code, QSA and QOutputDevice code are not touched
- *
- * Revision 1.36  2006/07/19 13:07:14  misuj1am
- *
- * -- doc update
- *
- * Revision 1.35  2006/07/02 14:03:55  misuj1am
- *
- * -- ADD: getXRef() helper function
- *
- * Revision 1.34  2006/06/29 20:00:07  hockm0bm
- * doc updated
- *
- * Revision 1.33  2006/06/21 18:46:00  hockm0bm
- * * CObject{Simple, Stream}, CDict, CArray
- *         - contains static const type field
- * * template helper functions with PropertyType template parameter changed to
- *   contain just Type parameter - original implementation kept but marked as
- *   deprecated (they will be removed when no deprecated warning is announced)
- *
- * Revision 1.32  2006/06/05 08:57:32  hockm0bm
- * refactoring CObjectSimple
- *         - getPropertyValue -> getValue
- *         - writeValue -> setValue
- *
- * Revision 1.31  2006/06/03 09:15:02  hockm0bm
- * getCObjectFromRef removed from cobjecthelpers.h to cpdf.h because gcc >=4.0
- * didn't like CPdf usage
- *
- * REMARK:
- * gcc 3.3 was ok with such construction
- *
- * Revision 1.30  2006/06/02 16:54:53  hockm0bm
- * checkAndReplace method added
- *
- * Revision 1.29  2006/06/02 11:54:44  hockm0bm
- * getCObjectFromRef(CPdf &, IndiRef) removed because it can't use CPdf and
- * implementation has to be in header file
- *
- * Revision 1.28  2006/06/02 10:48:46  hockm0bm
- * getCObjectFromRef template methods added
- *
- * Revision 1.27  2006/06/02 01:34:15  misuj1am
- *
- * -- ADD: support for getting all outlines dictionaries
- *
- * Revision 1.26  2006/05/30 20:48:05  hockm0bm
- * getIPropertyFromDate method added
- *
- * Revision 1.25  2006/05/30 17:27:00  hockm0bm
- * getIPropertyFromRectangle method added
- *
- * Revision 1.24  2006/05/09 20:03:47  hockm0bm
- * * getNameFromDict bug fix
- *         - Type used instead of /Type
- *
- * Revision 1.23  2006/05/01 13:53:06  hockm0bm
- * new style printDbg
- *
- * Revision 1.22  2006/04/25 22:16:16  misuj1am
- *
- * -- changes to MAKE it compile on my gcc [(GCC) 4.0.2 20051125 (Red Hat 4.0.2-8)]
- * 	-- only moved from one file to another
- * 	-- changed headers
- *
- * Revision 1.21  2006/04/25 02:26:17  misuj1am
- *
- * -- ADD: set*ToDict, set*ToArray improved to automaticly fetch object if ref
- *
- * Revision 1.20  2006/04/23 11:10:04  misuj1am
- *
- * -- small code improvment
- *
- * Revision 1.19  2006/04/23 09:45:33  misuj1am
- *
- * -- started using helper methods in iproperty.h isInValidPdf, isArray ..
- *
- * Revision 1.18  2006/04/21 11:02:07  misuj1am
- *
- * --Changes made by miso
- *
- * Revision 1.17  2006/04/20 22:30:47  hockm0bm
- * * IdCollector class added - helper fo getPropertyId
- * * getPropertyId
- *         - use parent->forEach method with IdCollector as functor
- *
- * Revision 1.16  2006/04/20 18:46:33  hockm0bm
- * correction of header - commited by mistake
- *
- * Revision 1.15  2006/04/20 18:02:59  hockm0bm
- * * operator== replaced by propertyEquals method
- * * parameters for getPropertyId and propertyEquals are const referencies
- * * getPropertyId - not useable now, because I don't have mechanism to get
- *         all available ids - but it is compileable
- *
- * Revision 1.14  2006/04/20 10:24:23  misuj1am
- *
- * --ADD getCSTreamFromArray
- *
- * Revision 1.13  2006/04/19 18:40:23  hockm0bm
- * * getPropertyId method implemented
- *         - compilation problems in linking stage (probably because of bad getAllPropertyNames implementation)
- * * operatator== for properties
- * 	- supports only pRef comparing now
- * * simpleEquals helper method for simple value comparing
- *
- * Revision 1.12  2006/04/13 18:14:09  hockm0bm
- * getDictFromRef with reference and pdf parameters
- *
- * Revision 1.11  2006/04/12 21:08:13  hockm0bm
- * printProperty method signature changed
- *         - no implicit parameter
- *         - output stream parameter is reference now
- *
- * Revision 1.10  2006/04/10 23:04:51  misuj1am
- *
- *
- * -- ADD: setValueToSimple, improved the code
- *
- * Revision 1.9  2006/04/09 21:27:13  misuj1am
- *
- *
- * -- getTypeFromDictionary returns shared_ptr<Type> that we want (if possible)
- * 	-- if CRef then try to fetch the indirect object and return it
- *
- * Revision 1.8  2006/04/07 10:23:02  misuj1am
- *
- * -- new observers, they are NOT called if an object changes
- *
- * Revision 1.7  2006/04/03 14:35:13  misuj1am
- *
- *
- * -- ADD: set (int/.../) methods for array
- *
- * Revision 1.6  2006/04/02 17:12:14  misuj1am
- *
- *
- * -- ADD get*FromArray, generic function, avaliable specification for Int and double
- *
- * Revision 1.5  2006/04/02 08:21:03  hockm0bm
- * printProperty helper method signature changed
- *         - stream parameter is not reference
- *         - default parameter is std::cout
- * implementation moved to cc file
- *
- * Revision 1.4  2006/04/01 20:43:48  hockm0bm
- * new output stream parameter for printProperty
- *
- * Revision 1.3  2006/04/01 20:30:03  hockm0bm
- * printProperty helper method for property printing
- *
- * Revision 1.2  2006/03/29 06:13:43  hockm0bm
- * getDictFromRef helper method added
- *
- * Revision 1.1  2006/03/24 17:37:57  hockm0bm
- * new file for helper methods for cobjects
- * in this time only for simple methods from dictionary
- *
- *
- */
+#include "kernel/cobject.h"
+#include "kernel/iproperty.h"
 
-#include "cobject.h"
-#include "iproperty.h"
-
-namespace pdfobjects
-{
-namespace utils
-{
+//=====================================================================================
+namespace pdfobjects {
+//=====================================================================================
+namespace utils {
+//=====================================================================================
 
 /** Gets type of the dictionary.
  * @param dict Dictionary wrapped in smart pointer.
@@ -392,7 +224,6 @@ public:
 	 */
 	void operator()(std::pair<IdType, boost::shared_ptr<IProperty> > entry)
 	{
-	using namespace debug;
 		try
 		{
 			// uses propertyEquals method to compare properties
@@ -400,13 +231,13 @@ public:
 			// simply ignore such values
 			if(comp(searched, entry.second))
 			{
-				utilsPrintDbg(DBG_DBG, "Element matches at id="<<entry.first);
+				utilsPrintDbg(debug::DBG_DBG, "Element matches at id="<<entry.first);
 				container.push_back(entry.first);
 			}
-		}catch(NotImplementedException & e)
+		}catch(NotImplementedException &)
 		{
 			// type of element is not supported
-			utilsPrintDbg(DBG_WARN, "Element comparing not supported for typ="<<entry.second->getType()<<". Ignoring element.");
+			utilsPrintDbg(debug::DBG_WARN, "Element comparing not supported for typ="<<entry.second->getType()<<". Ignoring element.");
 		}
 	}
 
@@ -449,11 +280,7 @@ public:
 template<typename Complex, typename Container > void 
 getPropertyId(const boost::shared_ptr<Complex> & parent, const boost::shared_ptr<IProperty> &child, Container & container) throw()
 {
-using namespace std;
-using namespace boost;
-using namespace debug;
-
-	utilsPrintDbg(DBG_DBG, "");
+	utilsPrintDbg(debug::DBG_DBG, "");
 
 	// collects all properties identificators which are same as child
 	// uses forEach with IdCollector functor
@@ -472,7 +299,7 @@ using namespace debug;
  *
  * @return Property (CArray) wrapped by smart pointer.
  */
-boost::shared_ptr<IProperty> getIPropertyFromRectangle(const Rectangle & rect);
+boost::shared_ptr<IProperty> getIPropertyFromRectangle(const libs::Rectangle & rect);
 
 /** Creates property with correct pdf time representation.
  * @param time Time to convert.
@@ -549,8 +376,11 @@ bool checkAndReplace(boost::shared_ptr<CDict> annotDict, std::string fieldName,
  */
 ::XRef* getXRef (boost::shared_ptr<IProperty> ip);
 
+//=====================================================================================
 }// end of utils namespace
-
+//=====================================================================================
 }// end of pdfobjects namespace
+//=====================================================================================
+
 #endif
 
